=== modified file 'plugin/heap/heap.h'
--- plugin/heap/heap.h	2010-08-12 23:14:19 +0000
+++ plugin/heap/heap.h	2010-08-13 00:46:27 +0000
@@ -27,6 +27,8 @@
 #include <plugin/myisam/my_handler.h>
 #include "drizzled/tree.h"
 
+#include <vector>
+
 	/* defines used by heap-funktions */
 
 #define HP_MAX_LEVELS	4		/* 128^5 records is enough */
@@ -265,8 +267,8 @@
   int lastinx,errkey;
   int  mode;				/* Mode of file (READONLY..) */
   uint32_t opt_flag,update;
-  unsigned char *lastkey;			/* Last used key with rkey */
-  unsigned char *recbuf;                         /* Record buffer for rb-tree keys */
+  std::vector <unsigned char> lastkey;			/* Last used key with rkey */
+  std::vector <unsigned char> recbuf;                         /* Record buffer for rb-tree keys */
   enum drizzled::ha_rkey_function last_find_flag;
   drizzled::TREE_ELEMENT *parents[drizzled::MAX_TREE_HEIGHT+1];
   drizzled::TREE_ELEMENT **last_pos;

=== modified file 'plugin/heap/hp_close.cc'
--- plugin/heap/hp_close.cc	2010-08-11 06:17:19 +0000
+++ plugin/heap/hp_close.cc	2010-08-13 00:46:27 +0000
@@ -41,8 +41,6 @@
   heap_open_list.remove(info);
   if (!--info->getShare()->open_count && info->getShare()->delete_on_close)
     hp_free(info->getShare());				/* Table was deleted */
-  delete [] info->lastkey;
-  delete [] info->recbuf;
   delete info;
   return(error);
 }

=== modified file 'plugin/heap/hp_delete.cc'
--- plugin/heap/hp_delete.cc	2010-08-10 01:34:18 +0000
+++ plugin/heap/hp_delete.cc	2010-08-13 00:46:27 +0000
@@ -70,10 +70,10 @@
     info->last_pos= NULL; /* For heap_rnext/heap_rprev */
 
   custom_arg.keyseg= keyinfo->seg;
-  custom_arg.key_length= hp_rb_make_key(keyinfo, info->recbuf, record, recpos);
+  custom_arg.key_length= hp_rb_make_key(keyinfo, &info->recbuf[0], record, recpos);
   custom_arg.search_flag= SEARCH_SAME;
   old_allocated= keyinfo->rb_tree.allocated;
-  res= tree_delete(&keyinfo->rb_tree, info->recbuf, custom_arg.key_length,
+  res= tree_delete(&keyinfo->rb_tree, &info->recbuf[0], custom_arg.key_length,
                    &custom_arg);
   info->getShare()->index_length-= (old_allocated - keyinfo->rb_tree.allocated);
   return res;

=== modified file 'plugin/heap/hp_hash.cc'
--- plugin/heap/hp_hash.cc	2010-08-11 21:21:09 +0000
+++ plugin/heap/hp_hash.cc	2010-08-13 00:46:27 +0000
@@ -70,10 +70,10 @@
   custom_arg.search_flag= SEARCH_FIND | SEARCH_SAME;
   if (min_key)
   {
-    custom_arg.key_length= hp_rb_pack_key(keyinfo, (unsigned char*) info->recbuf,
+    custom_arg.key_length= hp_rb_pack_key(keyinfo, &info->recbuf[0],
 					  (unsigned char*) min_key->key,
 					  min_key->keypart_map);
-    start_pos= tree_record_pos(rb_tree, info->recbuf, min_key->flag,
+    start_pos= tree_record_pos(rb_tree, &info->recbuf[0], min_key->flag,
 			       &custom_arg);
   }
   else
@@ -83,10 +83,10 @@
 
   if (max_key)
   {
-    custom_arg.key_length= hp_rb_pack_key(keyinfo, (unsigned char*) info->recbuf,
+    custom_arg.key_length= hp_rb_pack_key(keyinfo, &info->recbuf[0],
 					  (unsigned char*) max_key->key,
                                           max_key->keypart_map);
-    end_pos= tree_record_pos(rb_tree, info->recbuf, max_key->flag,
+    end_pos= tree_record_pos(rb_tree, &info->recbuf[0], max_key->flag,
 			     &custom_arg);
   }
   else

=== modified file 'plugin/heap/hp_open.cc'
--- plugin/heap/hp_open.cc	2010-08-12 23:14:19 +0000
+++ plugin/heap/hp_open.cc	2010-08-13 00:46:27 +0000
@@ -36,8 +36,8 @@
   share->open_count++;
   info->lock.init(&share->lock);
   info->setShare(share);
-  info->lastkey= new unsigned char[share->max_key_length];
-  info->recbuf= new unsigned char[share->max_key_length];
+  info->lastkey.resize(share->max_key_length);
+  info->recbuf.resize(share->max_key_length);
   info->mode= mode;
   info->current_record= UINT32_MAX;		/* No current record */
   info->lastinx= info->errkey= -1;

=== modified file 'plugin/heap/hp_rkey.cc'
--- plugin/heap/hp_rkey.cc	2010-08-10 01:34:18 +0000
+++ plugin/heap/hp_rkey.cc	2010-08-13 00:46:27 +0000
@@ -39,7 +39,7 @@
 
     custom_arg.keyseg= info->getShare()->keydef[inx].seg;
     custom_arg.key_length= info->lastkey_len=
-      hp_rb_pack_key(keyinfo, (unsigned char*) info->lastkey,
+      hp_rb_pack_key(keyinfo, &info->lastkey[0],
 		     (unsigned char*) key, keypart_map);
     custom_arg.search_flag= SEARCH_FIND | SEARCH_SAME;
     /* for next rkey() after deletion */
@@ -50,7 +50,7 @@
     else
       info->last_find_flag= find_flag;
     if (!(pos= (unsigned char *)tree_search_key(&keyinfo->rb_tree,
-                                                info->lastkey, info->parents,
+                                                &info->lastkey[0], info->parents,
 			                        &info->last_pos,
                                                 find_flag, &custom_arg)))
     {
@@ -68,7 +68,7 @@
       return(errno);
     }
     if (!(keyinfo->flag & HA_NOSAME))
-      memcpy(info->lastkey, key, (size_t) keyinfo->length);
+      memcpy(&info->lastkey[0], key, (size_t) keyinfo->length);
   }
   hp_extract_record(share, record, pos);
   info->update= HA_STATE_AKTIV;

=== modified file 'plugin/heap/hp_rnext.cc'
--- plugin/heap/hp_rnext.cc	2010-08-10 01:34:18 +0000
+++ plugin/heap/hp_rnext.cc	2010-08-13 00:46:27 +0000
@@ -76,7 +76,7 @@
       custom_arg.key_length = info->lastkey_len;
       custom_arg.search_flag = SEARCH_SAME | SEARCH_FIND;
       pos = (unsigned char *)tree_search_key(&keyinfo->rb_tree,
-                                             info->lastkey, info->parents,
+                                             &info->lastkey[0], info->parents,
                                              &info->last_pos,
                                              info->last_find_flag,
                                              &custom_arg);
@@ -95,7 +95,7 @@
   else
   {
     if (info->current_hash_ptr)
-      pos= hp_search_next(info, keyinfo, info->lastkey,
+      pos= hp_search_next(info, keyinfo, &info->lastkey[0],
 			   info->current_hash_ptr);
     else
     {
@@ -105,9 +105,9 @@
 	errno=HA_ERR_KEY_NOT_FOUND;
       }
       else if (!info->current_ptr)		/* Deleted or first call */
-	pos= hp_search(info, keyinfo, info->lastkey, 0);
+	pos= hp_search(info, keyinfo, &info->lastkey[0], 0);
       else
-	pos= hp_search(info, keyinfo, info->lastkey, 1);
+	pos= hp_search(info, keyinfo, &info->lastkey[0], 1);
     }
   }
   if (!pos)

=== modified file 'plugin/heap/hp_rprev.cc'
--- plugin/heap/hp_rprev.cc	2010-08-10 01:34:18 +0000
+++ plugin/heap/hp_rprev.cc	2010-08-13 00:46:27 +0000
@@ -46,7 +46,7 @@
       custom_arg.key_length = keyinfo->length;
       custom_arg.search_flag = SEARCH_SAME;
       pos = (unsigned char *)tree_search_key(&keyinfo->rb_tree,
-                                             info->lastkey, info->parents,
+                                             &info->lastkey[0], info->parents,
                                              &info->last_pos,
                                              info->last_find_flag,
                                              &custom_arg);
@@ -67,9 +67,9 @@
     if (info->current_ptr || (info->update & HA_STATE_NEXT_FOUND))
     {
       if ((info->update & HA_STATE_DELETED))
-        pos= hp_search(info, share->keydef + info->lastinx, info->lastkey, 3);
+        pos= hp_search(info, share->keydef + info->lastinx, &info->lastkey[0], 3);
       else
-        pos= hp_search(info, share->keydef + info->lastinx, info->lastkey, 2);
+        pos= hp_search(info, share->keydef + info->lastinx, &info->lastkey[0], 2);
     }
     else
     {

=== modified file 'plugin/heap/hp_rsame.cc'
--- plugin/heap/hp_rsame.cc	2010-08-10 01:34:18 +0000
+++ plugin/heap/hp_rsame.cc	2010-08-13 00:46:27 +0000
@@ -39,8 +39,8 @@
     else if (inx != -1)
     {
       info->lastinx=inx;
-      hp_make_key(share->keydef + inx, info->lastkey, record);
-      if (!hp_search(info, share->keydef + inx, info->lastkey, 3))
+      hp_make_key(share->keydef + inx, &info->lastkey[0], record);
+      if (!hp_search(info, share->keydef + inx, &info->lastkey[0], 3))
       {
 	info->update=0;
 	return(errno);

=== modified file 'plugin/heap/hp_write.cc'
--- plugin/heap/hp_write.cc	2010-08-10 01:34:18 +0000
+++ plugin/heap/hp_write.cc	2010-08-13 00:46:27 +0000
@@ -103,7 +103,7 @@
   uint32_t old_allocated;
 
   custom_arg.keyseg= keyinfo->seg;
-  custom_arg.key_length= hp_rb_make_key(keyinfo, info->recbuf, record, recpos);
+  custom_arg.key_length= hp_rb_make_key(keyinfo, &info->recbuf[0], record, recpos);
   if (keyinfo->flag & HA_NOSAME)
   {
     custom_arg.search_flag= SEARCH_FIND | SEARCH_UPDATE;
@@ -115,7 +115,7 @@
     keyinfo->rb_tree.flag= 0;
   }
   old_allocated= keyinfo->rb_tree.allocated;
-  if (!tree_insert(&keyinfo->rb_tree, (void*)info->recbuf,
+  if (!tree_insert(&keyinfo->rb_tree, &info->recbuf[0],
 		   custom_arg.key_length, &custom_arg))
   {
     errno= HA_ERR_FOUND_DUPP_KEY;

